@@ -5,7 +5,7 @@ use strict;
 use warnings;
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 1;
 
@@ -21,9 +21,21 @@ __END__
 
 =head1 SEE ALSO
 
-L<Video::Delay::Array>,
-L<Video::Delay::Const>,
-L<Video::Delay::Func>.
+=over
+
+=item L<Video::Delay::Array>
+
+Video::Delay class for predefined list of delays.
+
+=item L<Video::Delay::Const>
+
+Video::Delay class for constant delay.
+
+=item L<Video::Delay::Func>
+
+Video::Delay class for delays defined by math function.
+
+=back
 
 =head1 REPOSITORY
 
@@ -37,7 +49,8 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2012-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION 
 
