@@ -8,7 +8,7 @@ use warnings;
 use Class::Utils qw(set_params);
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -137,8 +137,13 @@ L<Class::Utils>.
 
 =head1 SEE ALSO
 
-L<Video::Delay::Const>,
-L<Video::Delay::Func>.
+=over
+
+=item L<Video::Delay>
+
+Perl classes for delays between frames generation.
+
+=back
 
 =head1 REPOSITORY
 
@@ -152,10 +157,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2012-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
