@@ -10,7 +10,7 @@ use English qw(-no_match_vars);
 use Error::Pure qw(err);
 
 # Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Constructor.
 sub new {
@@ -196,8 +196,13 @@ L<Error::Pure>.
 
 =head1 SEE ALSO
 
-L<Video::Delay::Array>,
-L<Video::Delay::Const>.
+=over
+
+=item L<Video::Delay>
+
+Perl classes for delays between frames generation.
+
+=back
 
 =head1 REPOSITORY
 
@@ -211,10 +216,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2012-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
